from numpy import array

from preprocess import preprocess
from feature_extract import get_feature_binary, get_feature_binary_mutualinformation, get_feature_tfidf

from sklearn.naive_bayes import MultinomialNB
from sklearn.linear_model import LogisticRegression
from sklearn.svm import SVC

from sklearn.metrics import classification_report

# training and prediction with Naive Bayesian classifier
def classify_NaiveBayesian(x, y, x_test):
    # train
    nbayes = MultinomialNB()
    nbayes.fit(x, y)
    # test 
    y_predict = nbayes.predict(x_test)
    return y_predict

# training and prediction with Logistic Regression classifier
def classify_Logistic(x, y, x_test):
    lr = LogisticRegression()
    lr.fit(x, y)
    y_predict = lr.predict(x_test)
    return y_predict

# training and prediction with SVM classifier
def classify_SVM(x, y, x_test):
    svm = SVC(kernel='linear')
    svm.fit(x, y)
    y_predict = svm.predict(x_test)
    return y_predict

# evaluation based on the predicted label and ground truth label
def evaluation(y_pred, y_test):
    print(classification_report(y_pred,y_test,target_names= ['not racist/sexist ', 'racist/sexist '],digits=3))
    return 0


if __name__ == "__main__":
    ##### 1. data preprocess #####
    x_train, y_train, x_test, y_test = preprocess() ## raw text

    ##### 2. feature extraction #####
    x = get_feature_binary(x_train + x_test)
    # x = get_feature_tfidf(x_train + x_test)
    # x = get_feature_binary_mutualinformation(x_train + x_test, y_train + y_test)
    x_train = x[:len(x_train)] ## feature vectors
    x_test = x[len(x_train):] ## feature vectors

    ##### 3. train the classifier and predict on test data #####
    y_predict = classify_NaiveBayesian(x_train, y_train, x_test)
    # y_predict = classify_SVM(x_train, y_train, x_test)
    # y_predict = classify_Logistic(x_train, y_train, x_test)

    ##### 4. evaluate the learned model and output result #####
    evaluation(y_predict, y_test)