from sklearn.feature_extraction.text import CountVectorizer, TfidfTransformer
from sklearn.feature_selection import mutual_info_classif
from preprocess import preprocess
from numpy import argmax, argsort, array

# get binary feature vectors from text
def get_feature_binary(sample_list):
    vectorizer = CountVectorizer()
    # data matrix
    data = vectorizer.fit_transform(sample_list).todense()
    data[data > 0] = 1
    # print(data)
    return data

# get binary feature vectors from text, and feature selection with top 50 mutual information 
def get_feature_binary_mutualinformation(sample_list, y_list):
    vectorizer = CountVectorizer()
    data = vectorizer.fit_transform(sample_list).todense()
    data[data > 0] = 1

    mutual_info = mutual_info_classif(data, y_list)
    index_mututal_info = argsort(-mutual_info)
    data = array(data)[:, index_mututal_info[:50]]
    print(data)

    return data

# get tf-idf feature vectors from text
def get_feature_tfidf(sample_list):
    vectorizer = CountVectorizer()
    data_count = vectorizer.fit_transform(sample_list)

    transformer = TfidfTransformer()
    tfidf = transformer.fit_transform(data_count).todense()
    return tfidf



if __name__ == "__main__":
    x_train, y_train, x_test, y_test = preprocess()
    x = get_feature_binary(x_train + x_test)
    result_test = get_feature_binary(x_test)