import csv
from nltk import word_tokenize
from nltk.stem.porter import PorterStemmer
from nltk.corpus import stopwords
import scapy


# to read x and y data from the csv file
def get_data_from_file(path_file):
    with open(path_file, 'r', encoding='utf-8') as file_input:
        csv_reader = csv.reader(file_input, delimiter = ',')
        next(csv_reader) # skip the header of csv file
        x_list = []
        y_list = []
        for row in csv_reader:
            x_list.append(row[2])
            y_list.append(row[1])
    return x_list, y_list


# text preprocessing using nltk package
def text_process(x_list):
    porter_stemmer = PorterStemmer()
    x_list_new = []
    for x in x_list:
        ####### Lower Case #######
        x = x.lower()

        ####### Tokenize #######
        x_token_list = word_tokenize(x)
        
        ####### Remove Stopwords #######
        x_token_list = [token for token in x_token_list if token not in stopwords.words('english')]

        ####### Stemming #######
        x_token_list = [porter_stemmer.stem(token) for token in x_token_list]

        x_new = ' '.join(x_token_list)
        x_list_new.append(x_new)
    
    return x_list_new



def preprocess():
    path_train = 'train.csv'
    path_test = 'test.csv'
    
    # obtain raw text from given files
    x_train, y_train = get_data_from_file(path_train)
    x_test, y_test = get_data_from_file(path_test)

    # text preprocess
    x_train = text_process(x_train)
    x_test = text_process(x_test)

    return x_train, y_train, x_test, y_test

    

if __name__ == "__main__":
    x_train, y_train, x_test, y_test = preprocess()
    print(x_train)
    print(y_train)
    